summaryrefslogtreecommitdiff
path: root/lib/chef/resource/execute.rb
diff options
context:
space:
mode:
authorLamont Granquist <lamont@scriptkiddie.org>2018-05-30 11:58:05 -0700
committerLamont Granquist <lamont@scriptkiddie.org>2018-05-30 11:58:05 -0700
commitc80702c741232a5da0d410d4b8770137690430aa (patch)
tree68bd656095ee70fc53d436d3fc52f196f20508ef /lib/chef/resource/execute.rb
parentfc98ec2b65e5a9a236f7374b831dcee6ab2100bb (diff)
downloadchef-c80702c741232a5da0d410d4b8770137690430aa.tar.gz
change "internal" to "default_env"
Signed-off-by: Lamont Granquist <lamont@scriptkiddie.org>
Diffstat (limited to 'lib/chef/resource/execute.rb')
-rw-r--r--lib/chef/resource/execute.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/chef/resource/execute.rb b/lib/chef/resource/execute.rb
index f9165ee487..7003b546fe 100644
--- a/lib/chef/resource/execute.rb
+++ b/lib/chef/resource/execute.rb
@@ -64,8 +64,8 @@ class Chef
property :group, [ String, Integer ]
property :live_stream, [ TrueClass, FalseClass ], default: false
- # internal defaults to `false` so that the command execution more exactly matches what the user gets on the command line without magic
- property :internal, [ TrueClass, FalseClass ], desired_state: false, default: false,
+ # default_env defaults to `false` so that the command execution more exactly matches what the user gets on the command line without magic
+ property :default_env, [ TrueClass, FalseClass ], desired_state: false, default: false,
description: "When true this enables ENV magic to add path_sanity to the PATH and force the locale to English+UTF-8 for parsing output"
property :returns, [ Integer, Array ], default: 0
property :timeout, [ Integer, Float ]